@@ -3,13 +3,25 @@
 var ES = require('../');
 var test = require('tape');
 var keys = require('object-keys');
-var forEach = require('foreach');
+var forEach = require('for-each');
 
 var ESkeys = keys(ES).sort();
 var ES6keys = keys(ES.ES6).sort();
 
 test('exposed properties', function (t) {
-	t.deepEqual(ESkeys, ES6keys.concat(['ES2021', 'ES2020', 'ES2019', 'ES2018', 'ES2017', 'ES7', 'ES2016', 'ES6', 'ES2015', 'ES5']).sort(), 'main ES object keys match ES6 keys');
+	t.deepEqual(ESkeys, ES6keys.concat([
+		'ES2022',
+		'ES2021',
+		'ES2020',
+		'ES2019',
+		'ES2018',
+		'ES2017',
+		'ES7',
+		'ES2016',
+		'ES6',
+		'ES2015',
+		'ES5'
+	]).sort(), 'main ES object keys match ES6 keys');
 	t.end();
 });
 
@@ -34,3 +46,4 @@ require('./es2018');
 require('./es2019');
 require('./es2020');
 require('./es2021');
+require('./es2022');
